import _objectSpread from '@babel/runtime/helpers/objectSpread2';
import { flexRender } from '@tanstack/react-table';
import { Table, Icon } from '@equinor/eds-core-react';
import { arrow_up, arrow_down } from '@equinor/eds-icons';
import { useTableContext } from '../EdsDataGridContext.js';
import { Filter } from './Filter.js';
import styled from 'styled-components';
import { tokens } from '@equinor/eds-tokens';
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';

var getSortLabel = function getSortLabel(sorted) {
  if (sorted) {
    return "".concat(sorted, "ending");
  }
  return 'none';
};
var Resizer = styled.div.withConfig({
  displayName: "TableHeaderCell__Resizer",
  componentId: "sc-1n0j3v0-0"
})(["transform:", ";opacity:", ";position:absolute;right:0;top:0;height:100%;width:5px;cursor:col-resize;user-select:none;touch-action:none;"], function (props) {
  return props.$columnResizeMode === 'onEnd' ? 'translateX(0px)' : 'none';
}, function (props) {
  return props.$isResizing ? 1 : 0;
});
var Cell = styled(Table.Cell).withConfig({
  displayName: "TableHeaderCell__Cell",
  componentId: "sc-1n0j3v0-1"
})(["font-weight:bold;height:30px;position:", ";&:hover ", "{background:", ";opacity:1;}"], function (p) {
  return p.sticky ? 'sticky' : 'relative';
}, Resizer, tokens.colors.interactive.primary__hover.rgba);
function TableHeaderCell(_ref) {
  var _asc$desc;
  var header = _ref.header,
    columnResizeMode = _ref.columnResizeMode;
  var ctx = useTableContext();
  var table = ctx.table;
  return header.isPlaceholder ? /*#__PURE__*/jsx(Cell, {
    sticky: ctx.stickyHeader,
    className: ctx.headerClass ? ctx.headerClass(header.column) : '',
    style: ctx.headerStyle ? ctx.headerStyle(header.column) : {},
    "aria-hidden": true
  }) : /*#__PURE__*/jsxs(Cell, {
    sticky: ctx.stickyHeader,
    className: ctx.headerClass ? ctx.headerClass(header.column) : '',
    "aria-sort": getSortLabel(header.column.getIsSorted()),
    onClick: header.column.getToggleSortingHandler(),
    key: header.id,
    colSpan: header.colSpan,
    style: _objectSpread({
      width: header.getSize(),
      verticalAlign: ctx.enableColumnFiltering ? 'baseline' : 'middle'
    }, ctx.headerStyle ? ctx.headerStyle(header.column) : {}),
    children: [/*#__PURE__*/jsxs(Fragment, {
      children: [/*#__PURE__*/jsxs("div", {
        style: {
          display: 'flex',
          flexDirection: 'column'
        },
        children: [/*#__PURE__*/jsx("span", {
          className: "table-header-cell-label",
          children: flexRender(header.column.columnDef.header, header.getContext())
        }), header.column.getCanFilter() ?
        /*#__PURE__*/
        // Supressing this warning - div is not interactive, but prevents propagation of events to avoid unintended sorting
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        jsx("div", {
          onClick: function onClick(e) {
            return e.stopPropagation();
          },
          children: /*#__PURE__*/jsx(Filter, {
            column: header.column,
            table: table
          })
        }) : null]
      }), (_asc$desc = {
        asc: /*#__PURE__*/jsx(Icon, {
          data: arrow_up
        }),
        desc: /*#__PURE__*/jsx(Icon, {
          data: arrow_down
        })
      }[header.column.getIsSorted()]) !== null && _asc$desc !== void 0 ? _asc$desc : null]
    }), columnResizeMode && /*#__PURE__*/jsx(Resizer, {
      onClick: function onClick(e) {
        return e.stopPropagation();
      },
      onMouseDown: header.getResizeHandler(),
      onTouchStart: header.getResizeHandler(),
      $isResizing: header.column.getIsResizing(),
      $columnResizeMode: columnResizeMode,
      className: 'resize-handle',
      "data-testid": 'resize-handle'
    })]
  });
}

export { TableHeaderCell };
